@@ -12,14 +12,13 @@ import datetime
 import os
 import re
 
-import six
 from django.apps import apps
 from django.db.models.fields.related import (
     ForeignKey, ManyToManyField, OneToOneField, RelatedField,
 )
 from django.contrib.contenttypes.fields import GenericRelation
 from django.template import Context, Template, loader
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils.safestring import mark_safe
 from django.utils.translation import activate as activate_language
 
@@ -55,7 +54,7 @@ def parse_file_or_list(arg):
     return [e.strip() for e in arg.split(',')]
 
 
-class ModelGraph(object):
+class ModelGraph:
     def __init__(self, app_labels, **kwargs):
         self.graphs = []
         self.cli_options = kwargs.get('cli_options', None)
@@ -111,7 +110,14 @@ class ModelGraph(object):
         }
 
         if as_json:
-            graph_data['graphs'] = [context.flatten() for context in self.graphs]
+            # We need to remove the model and field class because it is not JSON serializable
+            graphs = [context.flatten() for context in self.graphs]
+            for context in graphs:
+                for model_data in context['models']:
+                    model_data.pop('model')
+                    for field_data in model_data['fields']:
+                        field_data.pop('field')
+            graph_data['graphs'] = graphs
         else:
             graph_data['graphs'] = self.graphs
 
@@ -119,7 +125,7 @@ class ModelGraph(object):
 
     def add_attributes(self, field, abstract_fields):
         if self.verbose_names and field.verbose_name:
-            label = force_text(field.verbose_name)
+            label = force_str(field.verbose_name)
             if label.islower():
                 label = label.capitalize()
         else:
@@ -131,6 +137,7 @@ class ModelGraph(object):
         # TODO: ManyToManyField, GenericRelation
 
         return {
+            'field': field,
             'name': field.name,
             'label': label,
             'type': t,
@@ -142,7 +149,7 @@ class ModelGraph(object):
 
     def add_relation(self, field, model, extras=""):
         if self.verbose_names and field.verbose_name:
-            label = force_text(field.verbose_name)
+            label = force_str(field.verbose_name)
             if label.islower():
                 label = label.capitalize()
         else:
@@ -153,12 +160,12 @@ class ModelGraph(object):
             related_query_name = field.related_query_name()
             if self.verbose_names and related_query_name.islower():
                 related_query_name = related_query_name.replace('_', ' ').capitalize()
-            label = u'{} ({})'.format(label, force_text(related_query_name))
+            label = u'{} ({})'.format(label, force_str(related_query_name))
         if self.hide_edge_labels:
             label = ''
 
         # handle self-relationships and lazy-relationships
-        if isinstance(field.remote_field.model, six.string_types):
+        if isinstance(field.remote_field.model, str):
             if field.remote_field.model == 'self':
                 target_model = field.model
             else:
@@ -211,6 +218,7 @@ class ModelGraph(object):
 
     def get_appmodel_context(self, appmodel, appmodel_abstracts):
         context = {
+            'model': appmodel,
             'app_name': appmodel.__module__.replace(".", "_"),
             'name': appmodel.__name__,
             'abstracts': appmodel_abstracts,
@@ -219,7 +227,7 @@ class ModelGraph(object):
         }
 
         if self.verbose_names and appmodel._meta.verbose_name:
-            context['label'] = force_text(appmodel._meta.verbose_name)
+            context['label'] = force_str(appmodel._meta.verbose_name)
         else:
             context['label'] = context['name']
 
@@ -407,7 +415,7 @@ class ModelGraph(object):
 
 
 def generate_dot(graph_data, template='django_extensions/graph_models/digraph.dot'):
-    if isinstance(template, six.string_types):
+    if isinstance(template, str):
         template = loader.get_template(template)
 
     if not isinstance(template, Template) and not (hasattr(template, 'template') and isinstance(template.template, Template)):
